@@ -13,18 +13,18 @@ import mutagen
 
 def has_changed(song_cache, new_song_cache, fullpath):
     """Query song cache to know if file has changed (or is new) since last run.
-    In any case, update the cache.
-
-    Does not catch exceptions, can raise OS errors from os.stat."""
+       If it has, update the cache."""
     file_changed = False
     artist = None
     mtime = os.stat(fullpath).st_mtime
     if (fullpath not in song_cache) or (fullpath in song_cache and
-                                        song_cache[fullpath] != mtime):
+                                        song_cache[fullpath][0] != mtime):
         file_changed = True
         artist = get_artist(artist, fullpath)
     if file_changed:
         new_song_cache[fullpath] = [mtime, artist]
+    else:
+        new_song_cache[fullpath] = [mtime, song_cache[fullpath][1]]
     return new_song_cache, file_changed
 
 
