@@ -43,10 +43,8 @@ def test_pretty_strings():
     assert formatted_tuple == mfo.pretty_strings(concert)
 
 
-def test_atom(tmpdir):
+def test_atom(outdir):
     """Test function atom()"""
-    outdir = tmpdir.join('out')
-    outdir.mkdir()
     output = mfo.atom(CONCERT_LIST)
     # We need to write to a file, since this object is a
     # feedgenerator.django.utils.feedgenerator.Atom1Feed object
@@ -75,10 +73,8 @@ def test_json():
         assert valid_json == output
 
 
-def test_output_wrapper(tmpdir):
+def test_output_wrapper(outdir):
     """Test wrapper function output_wrapper()"""
-    outdir = tmpdir.join('out')
-    outdir.mkdir()
     output_path = os.path.join(outdir, 'foo.txt')
     mfo.output_wrapper(CONCERT_LIST, output_path)
     with open('tests/test_files/concerts.txt', 'r', encoding='utf-8') as file1:
